@@ -1,4 +1,4 @@
 import codenotes
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     codenotes.main()
